==> 5.7.7.zip: 5.7.7/engine/Shopware/Components/Api/Exception/ParameterMissingException.php <==
<?php
/**
 * Shopware 5
 * Copyright (c) shopware AG
 *
 * According to our dual licensing model, this program can be used either
 * under the terms of the GNU Affero General Public License, version 3,
 * or under a proprietary license.
 *
 * The texts of the GNU Affero General Public License with an additional
 * permission and of our proprietary license can be found at and
 * in the LICENSE file you have received along with this program.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * "Shopware" is a registered trademark of shopware AG.
 * The licensing of the program under the AGPLv3 does not imply a
 * trademark license. Therefore any rights, title and interest in
 * our trademarks remain entirely with us.
 */

namespace Shopware\Components\Api\Exception;

use Enlight_Exception;

/**
 * API Exception
 */
class ParameterMissingException extends Enlight_Exception
{
    /**
     * @var string|null
     */
    protected $missingParam = null;

    /**
     * @param string|null $param
     */
    public function __construct($param = '')
    {
        $this->setMissingParam($param);
        parent::__construct(sprintf('Missing parameter %s', $param));
    }

    /**
     * @param string|null $param
     */
    public function setMissingParam($param)
    {
        $this->missingParam = $param;
    }

    /**
     * @return string|null
     */
    public function getMissingParam()
    {
        return $this->missingParam;
    }
}

==> 5.7.14.zip: 5.7.14/engine/Shopware/Components/Api/Exception/ParameterMissingException.php <==
<?php

declare(strict_types=1);
/**
 * Shopware 5
 * Copyright (c) shopware AG
 *
 * According to our dual licensing model, this program can be used either
 * under the terms of the GNU Affero General Public License, version 3,
 * or under a proprietary license.
 *
 * The texts of the GNU Affero General Public License with an additional
 * permission and of our proprietary license can be found at and
 * in the LICENSE file you have received along with this program.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * "Shopware" is a registered trademark of shopware AG.
 * The licensing of the program under the AGPLv3 does not imply a
 * trademark license. Therefore any rights, title and interest in
 * our trademarks remain entirely with us.
 */

namespace Shopware\Components\Api\Exception;

use Enlight_Exception;
use RuntimeException;
use Symfony\Component\HttpFoundation\Response;

class ParameterMissingException extends Enlight_Exception implements ApiException
{
    /**
     * @var string
     */
    protected $missingParam;

    /**
     * @param string $param
     */
    public function __construct($param)
    {
        $this->setMissingParam($param);
        parent::__construct(sprintf('A required parameter is missing: %s', $param), Response::HTTP_BAD_REQUEST);
    }

    /**
     * @param string $param
     *
     * @return void
     */
    public function setMissingParam($param)
    {
        if (!\is_string($param)) {
            throw new RuntimeException('Missing Parameter needs to be configured');
        }
        $this->missingParam = $param;
    }

    /**
     * @return string
     */
    public function getMissingParam()
    {
        return $this->missingParam;
    }
}
